import os

import pytest
from itshire.add_sections import extract_headers


@pytest.fixture
def test_file_strong(tmp_path):
    test_file_path = tmp_path / "test_file_strong.md"
    with open(test_file_path, "w") as file:
        file.write("## **Section 1**\ntest")
    yield test_file_path
    os.remove(test_file_path)


@pytest.fixture
def test_file_italics(tmp_path):
    test_file_path = tmp_path / "test_file_italics.md"
    with open(test_file_path, "w") as file:
        file.write("## *Section 2*\ntest")
    yield test_file_path
    os.remove(test_file_path)


@pytest.fixture
def test_file_levels(tmp_path):
    test_file_path = tmp_path / "test_file_levels.md"
    with open(test_file_path, "w") as file:
        file.write(
            "# Level **1**\n## Level *2*\n### **Level** 3\n#### *Level* 4\n##### Level ***5***"
        )
    yield test_file_path
    os.remove(test_file_path)


@pytest.fixture
def test_file_inline_code(tmp_path):
    test_file_path = tmp_path / "test_file_inline_code.md"
    with open(test_file_path, "w") as file:
        file.write(
            "# Section `code`\n## Section *`code`*\n### Section **`code`**\n#### `Section` *code*\n##### **`Section`** `code`"
        )
    yield test_file_path
    os.remove(test_file_path)


def test_extract_headers_strong(test_file_strong):
    headers = extract_headers(test_file_strong)
    assert headers == ["Section 1"]


def test_extract_headers_italics(test_file_italics):
    headers = extract_headers(test_file_italics)
    assert headers == ["Section 2"]


def test_extract_headers_levels(test_file_levels):
    headers = extract_headers(test_file_levels)
    assert headers == ["Level 1", "Level 2", "Level 3", "Level 4", "Level 5"]


def test_extract_headers_inline_code(test_file_inline_code):
    headers = extract_headers(test_file_inline_code)
    assert headers == [
        "Section code",
        "Section code",
        "Section code",
        "Section code",
        "Section code",
    ]


@pytest.fixture
def test_file_internal_links(tmp_path):
    test_file_path = tmp_path / "test_file_internal_links.md"
    with open(test_file_path, "w") as file:
        file.write(
            "# Section [[link1]]\n"
            "## Section [[link2]] with text\n"
            "### **Section** [[link3]] and *more* text\n"
            "#### Section with [[link4]] and `code`\n"
            "##### [[link5]] at the beginning"
        )
    yield test_file_path
    os.remove(test_file_path)


def test_extract_headers_internal_links(test_file_internal_links):
    headers = extract_headers(test_file_internal_links)
    assert headers == [
        "Section [[link1]]",
        "Section [[link2]] with text",
        "Section [[link3]] and more text",
        "Section with [[link4]] and code",
        "[[link5]] at the beginning",
    ]



import mistletoe


def extract_headers(file_path):
    with open(file_path, "r") as file:
        markdown_content = file.read()

    parsed_markdown = mistletoe.Document(markdown_content)
    headers = []

    def _traverse(node):
        if isinstance(node, mistletoe.block_token.Heading):
            headers.append(node.children[0].content)
        for child in getattr(node, "children", []):
            _traverse(child)

    _traverse(parsed_markdown)
    return headers


file_path = "/Users/mtm/Documents/Obsidian Vault/Lime.md"
headers = extract_headers(file_path)
sorted_headers = sorted(headers)

print("Sorted headers:")
for header in sorted_headers:
    print(header)



import logging
import pathlib

import frontmatter
import mistletoe


def extract_headers(file_path):
    with open(file_path, "r") as file:
        markdown_content = file.read()
    parsed_markdown = mistletoe.Document(markdown_content)
    headers = []

    def _traverse(node):
        if isinstance(node, mistletoe.block_token.Heading):
            header_text = "".join(_extract_text(child) for child in node.children)
            headers.append(header_text.strip())
        for child in getattr(node, "children", []):
            _traverse(child)

    def _extract_text(node):
        if isinstance(node, mistletoe.span_token.RawText):
            return node.content
        elif isinstance(node, mistletoe.span_token.InlineCode):
            return node.children[0].content
        else:
            return "".join(_extract_text(child) for child in node.children)

    _traverse(parsed_markdown)
    return headers


def add_sections(file_path, section_names):
    with open(file_path, "r") as file:
        markdown_content = file.read()

    original_content = markdown_content

    for section_name in section_names:
        if section_name not in markdown_content:
            markdown_content += f"\n## [[{section_name}]]\n- [x] shopping\n"

    if markdown_content != original_content:
        with open(file_path, "w") as file:
            file.write(markdown_content)


def find_markdown_files(directory):
    return list(pathlib.Path(directory).rglob("*.md"))


def filter_markdown_files(files):
    filtered_files = []
    for file in files:
        try:
            with open(file, "r", encoding="utf-8") as f:
                post = frontmatter.load(f)
                if post.get("filetype") == "product":
                    filtered_files.append(file)
        except Exception as e:
            logging.error(f"Error processing file {file}: {str(e)}")
    return filtered_files


def main(directory):
    markdown_files = find_markdown_files(directory)
    filtered_files = filter_markdown_files(markdown_files)
    logging.debug(f"Filtered files: {filtered_files}")

    stores = [
        "Amazon.com",
        "Central Co-op",
        "Grocery Outlet",
        "Hau Hau Market",
        "Lam's Seafood Asian Market",
        "M2M",
        "PCC",
        "QFC",
        "Safeway",
        "Trader Joes",
        "Uwajimaya",
        "Whole Foods",
    ]

    for file_path in filtered_files:
        logging.info(f"Processing file: {file_path}")
        existing_headers = extract_headers(file_path)
        missing_sections = [
            store_name for store_name in stores if store_name not in existing_headers
        ]
        if missing_sections:
            add_sections(file_path, missing_sections)

    print("Sections added successfully.")
